Restlax (Restlax v1.0.1)

Copy Markdown View Source

hex.pm hex.pm github.com

Relax, it's just REST.

Built on top of Req for a consistent HTTP transport.

Features

  • quick generation of regular REST actions
  • helpers to aid writing custom actions
  • request-level customization via req/1 callback

Installation

If available in Hex, the package can be installed by adding restlax to your list of dependencies in mix.exs:

def deps do
  [
    {:restlax, "~> 1.0.1"}
  ]
end

Usage

See Restlax.Client and Restlax.Resource for more information

The docs can be found at https://hexdocs.pm/restlax.

An example project using Restlax: Cloudflare