Relax, it's just REST.
Built on top of Req for a consistent HTTP transport.
Features
- quick generation of regular REST actions
- helpers to aid writing custom actions
- request-level customization via
req/1callback
Installation
If available in Hex, the package can be installed
by adding restlax to your list of dependencies in mix.exs:
def deps do
[
{:restlax, "~> 1.0.1"}
]
endUsage
See Restlax.Client and Restlax.Resource for more information
The docs can be found at https://hexdocs.pm/restlax.
An example project using Restlax: Cloudflare